@@ -3,7 +3,7 @@
 from tkinter import *
 import os
 veri = Tk()
-veri.title('Kyak2-systemd-installer')
+veri.title('Kyak2-Void-guinstaller')
 veri.geometry('400x225')
 veri.configure(bg='#252726')
 veri.maxsize(400,225)
